diff --git a/ImageAnalyzer/nbproject/project.properties b/ImageAnalyzer/nbproject/project.properties
index c71cea41512e07507d11ac5af4b6855682d735a6..e6fc48149fbebaebe3f4cf669e0dccbfa63751c3 100644
--- a/ImageAnalyzer/nbproject/project.properties
+++ b/ImageAnalyzer/nbproject/project.properties
@@ -4,4 +4,4 @@ javac.compilerargs=-Xlint -Xlint:-serial
 license.file=LICENSE-2.0.txt
 nbm.homepage=http://www.sleuthkit.org/
 nbm.needs.restart=true
-project.license=eureka
+project.license=imageanalyzer
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/AutopsyListener.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/AutopsyListener.java
index 4f4d78cabe5bf1f8852ee399b6a8a8db46f41940..2f97f004283313e4961a81fc984f6c3234258bf9 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/AutopsyListener.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/AutopsyListener.java
@@ -98,7 +98,7 @@ synchronized public void propertyChange(PropertyChangeEvent evt) {
                     /* we could listen to DATA events and progressivly update
                      * files, and get data from DataSource ingest modules, but
                      * given that most modules don't post new artifacts in the
-                     * events and eureka would have to query for them, without
+                     * events and we would have to query for them, without
                      * knowing which are the new ones, we just ignore these
                      * events for now. The relevant data should all be captured
                      * by file done event, anyways -jm */
@@ -141,14 +141,14 @@ synchronized public void propertyChange(PropertyChangeEvent evt) {
                         controller.setCase(newCase);
 
                     } else { // case is closing
-                        //close eureka window
+                        //close window
                         SwingUtilities.invokeLater(ImageAnalyzerModule::closeTopComponent);
                         controller.reset();
                     }
                     break;
 
                 case DATA_SOURCE_ADDED:
-                    //copy all file data to eureka databse
+                    //copy all file data to drawable databse
                     Content newDataSource = (Content) evt.getNewValue();
                     if (controller.isListeningEnabled()) {
                         controller.queueTask(controller.new PrePopulateDataSourceFiles(newDataSource.getId()));
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerModule.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerModule.java
index 4b51b1d2564b7e649209678265d856ae155e4022..2929ba4c23c07b9ff2c77c335749729d68500009 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerModule.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerModule.java
@@ -18,7 +18,6 @@
  */
 package org.sleuthkit.autopsy.imageanalyzer;
 
-import org.sleuthkit.autopsy.coreutils.ThreadConfined;
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Sets;
 import java.util.ArrayList;
@@ -35,13 +34,14 @@
 import org.sleuthkit.autopsy.casemodule.Case;
 import org.sleuthkit.autopsy.coreutils.ImageUtils;
 import org.sleuthkit.autopsy.coreutils.Logger;
+import org.sleuthkit.autopsy.coreutils.ThreadConfined;
 import org.sleuthkit.autopsy.imageanalyzer.datamodel.DrawableDB;
 import org.sleuthkit.datamodel.AbstractFile;
 import org.sleuthkit.datamodel.BlackboardAttribute;
 import org.sleuthkit.datamodel.TskCoreException;
 import org.sleuthkit.datamodel.TskData;
 
-/** static definitions and utilities for the Eureka Module
+/** static definitions and utilities for the ImageAnalyzer module
  *
  */
 public class ImageAnalyzerModule {
@@ -154,15 +154,15 @@ static public boolean isSupportedAndNotKnown(AbstractFile abstractFile) {
         return (abstractFile.getKnown() != TskData.FileKnown.KNOWN) && ImageAnalyzerModule.isSupported(abstractFile);
     }
 
-    //TODO: this doesn ot really belong here, move it to EurekaController? Module?
+    //TODO: this doesn ot really belong here, move it to ImageAnalyzerController? Module?
     @ThreadConfined(type = ThreadConfined.ThreadType.UI)
     public static void closeTopComponent() {
-        final TopComponent etc = WindowManager.getDefault().findTopComponent("EurekaTopComponent");
+        final TopComponent etc = WindowManager.getDefault().findTopComponent("ImageAnalyzerTopComponent");
         if (etc != null) {
             try {
                 etc.close();
             } catch (Exception e) {
-                LOGGER.log(Level.SEVERE, "failed to close EurekaTopComponent", e);
+                LOGGER.log(Level.SEVERE, "failed to close ImageAnalyzerTopComponent", e);
             }
         }
     }
@@ -177,16 +177,16 @@ public static void openTopComponent() {
 //            }
 //        }
 //        timeLineController.openTimeLine();
-        final ImageAnalyzerTopComponent EurekaTc = (ImageAnalyzerTopComponent) WindowManager.getDefault().findTopComponent("EurekaTopComponent");
-        if (EurekaTc != null) {
-            WindowManager.getDefault().isTopComponentFloating(EurekaTc);
+        final ImageAnalyzerTopComponent tc=  (ImageAnalyzerTopComponent) WindowManager.getDefault().findTopComponent("ImageAnalyzerTopComponent");
+        if (tc != null) {
+            WindowManager.getDefault().isTopComponentFloating(tc);
             Mode mode = WindowManager.getDefault().findMode("timeline");
             if (mode != null) {
-                mode.dockInto(EurekaTc);
+                mode.dockInto(tc);
 
             }
-            EurekaTc.open();
-            EurekaTc.requestActive();
+            tc.open();
+            tc.requestActive();
         }
     }
 }
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/TagUtils.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/TagUtils.java
index 362af325685d87afe4c23f6288533c9033a562f3..e37e0a5924e096aa74e016125e1e80dc9680a146 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/TagUtils.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/TagUtils.java
@@ -38,7 +38,7 @@
 import org.sleuthkit.datamodel.TskCoreException;
 
 /**
- * Contains static methods for dealing with Tags in Eureka
+ * Contains static methods for dealing with Tags in ImageAnalyzer
  */
 public class TagUtils {
 
@@ -134,7 +134,7 @@ public static void unregisterListener(TagListener aThis) {
     /**
      *
      * @param tn            the value of tn
-     * @param eurekaToolbar the value of eurekaToolbar
+     
      */
     static public MenuItem createSelTagMenuItem(final TagName tn, final SplitMenuButton tagSelectedMenuButton) {
         final MenuItem menuItem = new MenuItem(tn.getDisplayName(), new ImageView(DrawableAttribute.TAGS.getIcon()));
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/actions/OpenAction.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/actions/OpenAction.java
index 16ea28a8096943752dab66d6b62ee1ff27937dc5..68f7aaf3bf3020940ea25340859600f1eb4ecb71 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/actions/OpenAction.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/actions/OpenAction.java
@@ -43,7 +43,7 @@
 @Messages("CTL_OpenAction=Analyze Images/Videos")
 public final class OpenAction extends CallableSystemAction {
 
-    private final String EUREKA = "Analyze Images/Videos";
+    private final String Analyze_Images_Videos = "Analyze Images/Videos";
 
     private static final boolean fxInited = Installer.isJavaFxInited();
 
@@ -64,7 +64,7 @@ public boolean isEnabled() {
     @Override
     public Component getToolbarPresenter() {
         JButton toolbarButton = new JButton(this);
-        toolbarButton.setText(EUREKA);
+        toolbarButton.setText(Analyze_Images_Videos);
         toolbarButton.addActionListener(this);
 
         return toolbarButton;
@@ -106,7 +106,7 @@ public void performAction() {
 
     @Override
     public String getName() {
-        return EUREKA;
+        return Analyze_Images_Videos;
     }
 
     @Override
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/Category.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/Category.java
index 3d9e9dfc1c5611625eb7497cdfc9cfe6990394a5..da87827afe0f8eb9a1f43a79a30e8d266a18414b 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/Category.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/Category.java
@@ -18,8 +18,6 @@
  */
 package org.sleuthkit.autopsy.imageanalyzer.datamodel;
 
-import org.sleuthkit.autopsy.imageanalyzer.TagUtils;
-import org.sleuthkit.autopsy.imageanalyzer.actions.CategorizeAction;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
@@ -37,6 +35,8 @@
 import javafx.scene.paint.Color;
 import javax.annotation.concurrent.GuardedBy;
 import org.sleuthkit.autopsy.coreutils.Logger;
+import org.sleuthkit.autopsy.imageanalyzer.TagUtils;
+import org.sleuthkit.autopsy.imageanalyzer.actions.CategorizeAction;
 import org.sleuthkit.datamodel.TagName;
 import org.sleuthkit.datamodel.TskCoreException;
 
@@ -143,7 +143,6 @@ public MenuItem createSelCatMenuItem(final SplitMenuButton catSelectedMenuButton
         menuItem.setOnAction(new EventHandler<ActionEvent>() {
             @Override
             public void handle(ActionEvent t) {
-                //                        EurekaTileSelectionModel.getInstance().clearAndSelectAll(getTiles().toArray(new DrawableTile[getTiles().size()]));
                 new CategorizeAction().addTag(Category.this.getTagName(), "");
                 catSelectedMenuButton.setText(Category.this.getDisplayName());
                 catSelectedMenuButton.setOnAction(this);
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/ImageFile.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/ImageFile.java
index 70c0c050521e5852c61bbacd08ecc39f2df7aeac..c91c28651a2d71b5e9759aff431ff6fb12fe4d6a 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/ImageFile.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/datamodel/ImageFile.java
@@ -18,8 +18,6 @@
  */
 package org.sleuthkit.autopsy.imageanalyzer.datamodel;
 
-import org.sleuthkit.autopsy.imageanalyzer.IconCache;
-import org.sleuthkit.autopsy.imageanalyzer.gui.Fitable;
 import java.awt.image.BufferedImage;
 import java.io.IOException;
 import java.lang.ref.SoftReference;
@@ -31,12 +29,14 @@
 import javax.imageio.ImageIO;
 import org.sleuthkit.autopsy.casemodule.Case;
 import org.sleuthkit.autopsy.coreutils.Logger;
+import org.sleuthkit.autopsy.imageanalyzer.IconCache;
+import org.sleuthkit.autopsy.imageanalyzer.gui.Fitable;
 import org.sleuthkit.datamodel.AbstractFile;
 import org.sleuthkit.datamodel.ReadContentInputStream;
 import org.sleuthkit.datamodel.TskCoreException;
 
 /**
- * Eureka data model object that represents an image file. It is a
+ * ImageAnalyzer data model object that represents an image file. It is a
  * wrapper(/decorator?/adapter?) around {@link AbstractFile} and provides
  * methods to get an icon sized and a full sized {@link  Image}.
  *
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/grouping/GroupSortBy.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/grouping/GroupSortBy.java
index a75d0f32caf7199ed33f54858edc6bd70b85595e..f8692bdf1402690bd0fd9458b670373d82a151f4 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/grouping/GroupSortBy.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/grouping/GroupSortBy.java
@@ -32,7 +32,7 @@
 
 /**
  * enum of possible properties to sort groups by. This is the model for the drop
- * down in {@link  EurekaToolbar} as well as each enum value having the stategy
+ * down in Toolbar as well as each enum value having the stategy
  * ({@link  Comparator}) for sorting the groups
  */
 public enum GroupSortBy implements ComparatorProvider {
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/gui/Toolbar.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/gui/Toolbar.java
index 7a98548b0a499a4c37e3106aac71dc4b27d81a68..7873711fbe44a6a66358e91c14e19a6d679e9ea0 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/gui/Toolbar.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/gui/Toolbar.java
@@ -132,16 +132,16 @@ static synchronized public Toolbar getDefault() {
 
     @FXML
     void initialize() {
-        assert ascRadio != null : "fx:id=\"ascRadio\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert catSelectedMenuButton != null : "fx:id=\"catSelectedMenubutton\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert descRadio != null : "fx:id=\"descRadio\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert groupByBox != null : "fx:id=\"groupByBox\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert onlyAnalyzedCheckBox != null : "fx:id=\"onlyAnalyzedCheckBox\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert orderGroup != null : "fx:id=\"orderGroup\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert sizeSlider != null : "fx:id=\"sizeSlider\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert sortByBox != null : "fx:id=\"sortByBox\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert sortControlGroup != null : "fx:id=\"sortControlGroup\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
-        assert tagSelectedMenuButton != null : "fx:id=\"tagSelectedMenubutton\" was not injected: check your FXML file 'EurekaToolbar.fxml'.";
+        assert ascRadio != null : "fx:id=\"ascRadio\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert catSelectedMenuButton != null : "fx:id=\"catSelectedMenubutton\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert descRadio != null : "fx:id=\"descRadio\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert groupByBox != null : "fx:id=\"groupByBox\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert onlyAnalyzedCheckBox != null : "fx:id=\"onlyAnalyzedCheckBox\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert orderGroup != null : "fx:id=\"orderGroup\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert sizeSlider != null : "fx:id=\"sizeSlider\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert sortByBox != null : "fx:id=\"sortByBox\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert sortControlGroup != null : "fx:id=\"sortControlGroup\" was not injected: check your FXML file 'Toolbar.fxml'.";
+        assert tagSelectedMenuButton != null : "fx:id=\"tagSelectedMenubutton\" was not injected: check your FXML file 'Toolbar.fxml'.";
 
         FileIDSelectionModel.getInstance().getSelected().addListener((Observable o) -> {
             Runnable r = () -> {
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerController.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerController.java
index 7dc6de1ef02b59b8f8ae559023aa143bfc295af9..6614acb70e2bf6d8b1df0df296f236dd2191a694 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerController.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerController.java
@@ -22,7 +22,6 @@
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
-import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.ExecutorService;
@@ -93,7 +92,7 @@
  * Acts as the controller in GroupManager - GroupListPane -
  * ImageAnalyzerController MVC Trio
  *
  * Connects different parts of Eureka together and is hub for flow of control.
  */
 public class ImageAnalyzerController implements FileUpdateListener {
 
@@ -471,7 +470,7 @@ synchronized public void handleFileUpdate(FileUpdateEvent evt) {
      * reset the state of the controller (eg if the case is closed)
      */
     public synchronized void reset() {
-        LOGGER.info("resetting EurekaControler to initial state.");
+        LOGGER.info("resetting ImageAnalyzerControler to initial state.");
         selectionModel.clearSelection();
         Platform.runLater(() -> {
             historyManager.clear();
@@ -737,7 +736,7 @@ public void run() {
     }
 
     /**
      * Task that runs when eureka listening is (re) enabled.
      *
      * Uses the presence of TSK_FILE_TYPE_SIG attributes as a approximation to
      * 'analyzed'. Grabs all files with supported image/video mime types, and
@@ -836,7 +835,7 @@ public void run() {
      * (uses fs_obj_id to identify files from new datasource) *
      *
      * TODO: create methods to simplify progress value/text updates to both
      * netbeans and eureka progress/status
      */
     class PrePopulateDataSourceFiles extends TaskWithID {
 
@@ -93,7 +92,7 @@
  * ImageAnalyzerController MVC Trio
  *
- * Connects different parts of Eureka together and is hub for flow of control.
+ * Connects different parts of ImageAnalyzer together and is hub for flow of control.
  */
 public class ImageAnalyzerController implements FileUpdateListener {
@@ -737,7 +736,7 @@ public void run() {
 
     /**
-     * Task that runs when eureka listening is (re) enabled.
+     * Task that runs when image analyzer listening is (re) enabled.
      *
      * Uses the presence of TSK_FILE_TYPE_SIG attributes as a approximation to
@@ -836,7 +835,7 @@ public void run() {
      *
      * TODO: create methods to simplify progress value/text updates to both
-     * netbeans and eureka progress/status
+     * netbeans and ImageAnalyzer progress/status
      */
     class PrePopulateDataSourceFiles extends TaskWithID {
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerTopComponent.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerTopComponent.java
index 18c03780e396ea76a25f10f085d7ef81224df29f..ce891c4c5c19a80d1361be1c63fa3645cb656607 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerTopComponent.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/ImageAnalyzerTopComponent.java
@@ -31,32 +31,32 @@
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle.Messages;
 import org.openide.windows.TopComponent;
-import org.sleuthkit.autopsy.imageanalyzer.gui.Toolbar;
 import org.sleuthkit.autopsy.imageanalyzer.gui.GroupPane;
 import org.sleuthkit.autopsy.imageanalyzer.gui.MetaDataPane;
 import org.sleuthkit.autopsy.imageanalyzer.gui.StatusBar;
 import org.sleuthkit.autopsy.imageanalyzer.gui.SummaryTablePane;
+import org.sleuthkit.autopsy.imageanalyzer.gui.Toolbar;
 import org.sleuthkit.autopsy.imageanalyzer.gui.navpanel.NavPanel;
 
 /**
  * Top component which displays eureka interface.
  */
 @ConvertAsProperties(
-        dtd = "-//org.sleuthkit.autopsy.imageanalyzer//Eureka//EN",
+        dtd = "-//org.sleuthkit.autopsy.imageanalyzer//ImageAnalyzer//EN",
         autostore = false)
 @TopComponent.Description(
-        preferredID = "EurekaTopComponent",
+        preferredID = "ImageAnalyzerTopComponent",
         //iconBase = "org/sleuthkit/autopsy/imageanalyzer/images/lightbulb.png",
         persistenceType = TopComponent.PERSISTENCE_NEVER)
 @TopComponent.Registration(mode = "timeline", openAtStartup = false)
 @Messages({
-    "CTL_EurekaAction=Image/Video Analysis",
-    "CTL_EurekaTopComponent=Image/Video Analysis",
-    "HINT_EurekaTopComponent=This is a Image/Video Analysis window"
+    "CTL_ImageAnalyzerAction=Image/Video Analysis",
+    "CTL_ImageAnalyzerTopComponent=Image/Video Analysis",
+    "HINT_ImageAnalyzerTopComponent=This is a Image/Video Analysis window"
 })
 public final class ImageAnalyzerTopComponent extends TopComponent implements ExplorerManager.Provider, Lookup.Provider {
 
-    public final static String PREFERRED_ID = "EurekaTopComponent";
+    public final static String PREFERRED_ID = "ImageAnalyzerTopComponent";
 
     private final ExplorerManager em = new ExplorerManager();
 
@@ -84,8 +84,8 @@ public final class ImageAnalyzerTopComponent extends TopComponent implements Exp
 
     public ImageAnalyzerTopComponent() {
 
-        setName(Bundle.CTL_EurekaTopComponent());
-        setToolTipText(Bundle.HINT_EurekaTopComponent());
+        setName(Bundle.CTL_ImageAnalyzerTopComponent());
+        setToolTipText(Bundle.HINT_ImageAnalyzerTopComponent());
 
         // ...and initialization of lookup variable
         lookup = (ExplorerUtils.createLookup(em, getActionMap()));
@@ -31,32 +31,32 @@
 
 /**
- * Top component which displays eureka interface.
+ * Top component which displays ImageAnalyzer interface.
  */
 @ConvertAsProperties(
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/OnStart.java b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/OnStart.java
index 7234fa1b9509d701a005f76d19a9ddb7574e8746..eec1a68ef583b4b0a7fa3ac0c5d5fe532e547b46 100644
--- a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/OnStart.java
+++ b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/OnStart.java
@@ -26,7 +26,7 @@
 /**
  *
  * The {@link OnStart} annotation tells NetBeans to invoke this class's
- * {@link EurekaModule#run()} method
+ * {@link ImageAnalyzerModule#run()} method
  */
 @org.openide.modules.OnStart
 public class OnStart implements Runnable {
@@ -34,17 +34,17 @@ public class OnStart implements Runnable {
     static private final Logger LOGGER = Logger.getLogger(OnStart.class.getName());
 
     /**
      * make sure that the eureka listeners get setup as early as possible, and
      * do other setup stuff.
      *
      * This method is invoked by virtue of the {@link OnStart} annotation on the
-     * {@link EurekaModule} class
+     * {@link ImageAnalyzerModule} class
      */
     @Override
     public void run() {
         Platform.setImplicitExit(false);
 
-        LOGGER.info("setting up eureka listeners");
+        LOGGER.info("setting up ImageAnalyzer listeners");
 
         IngestManager.getInstance().addIngestJobEventListener(AutopsyListener.getDefault().getIngestJobEventListener());
         IngestManager.getInstance().addIngestModuleEventListener(AutopsyListener.getDefault().getIngestModuleEventListener());
@@ -34,17 +34,17 @@ public class OnStart implements Runnable {
 
     /**
-     * make sure that the eureka listeners get setup as early as possible, and
+     * make sure that the ImageAnalyzer listeners get setup as early as possible, and
      * do other setup stuff.
      *
diff --git a/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/license-eureka.txt b/ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/license-imageanalyzer.txt
similarity index 100%
rename from ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/license-eureka.txt
rename to ImageAnalyzer/src/org/sleuthkit/autopsy/imageanalyzer/license-imageanalyzer.txt